From: Mike Snitzer <snitzer@redhat.com>

Avoid private module usage accounting by removing 'use' from
dm_dirty_log_internal.  The standard module reference counting is
sufficient.

Signed-off-by: Mike Snitzer <snitzer@redhat.com>
Signed-off-by: Alasdair G Kergon <agk@redhat.com>
---
 drivers/md/dm-log.c |   19 +++----------------
 1 files changed, 3 insertions(+), 16 deletions(-)

Index: linux-2.6.29/drivers/md/dm-log.c
===================================================================
--- linux-2.6.29.orig/drivers/md/dm-log.c	2009-04-02 16:34:52.000000000 +0100
+++ linux-2.6.29/drivers/md/dm-log.c	2009-04-02 16:49:33.000000000 +0100
@@ -20,7 +20,6 @@ struct dm_dirty_log_internal {
 	struct dm_dirty_log_type *type;
 
 	struct list_head list;
-	long use;
 };
 
 static LIST_HEAD(_log_types);
@@ -44,12 +43,8 @@ static struct dm_dirty_log_internal *_ge
 	spin_lock(&_lock);
 
 	log_type = __find_dirty_log_type(name);
-	if (log_type) {
-		if (!log_type->use && !try_module_get(log_type->type->module))
-			log_type = NULL;
-		else
-			log_type->use++;
-	}
+	if (log_type && !try_module_get(log_type->type->module))
+		log_type = NULL;
 
 	spin_unlock(&_lock);
 
@@ -120,10 +115,7 @@ static void put_type(struct dm_dirty_log
 	if (!log_type)
 		goto out;
 
-	if (!--log_type->use)
-		module_put(type->module);
-
-	BUG_ON(log_type->use < 0);
+	module_put(type->module);
 
 out:
 	spin_unlock(&_lock);
@@ -173,11 +165,6 @@ int dm_dirty_log_type_unregister(struct 
 		return -EINVAL;
 	}
 
-	if (log_type->use) {
-		spin_unlock(&_lock);
-		return -ETXTBSY;
-	}
-
 	list_del(&log_type->list);
 
 	spin_unlock(&_lock);
